#!/usr/bin/perl

# This script runs benchmarks with the cheetahtool and plots the results using gnuplot.

$pindir = $ENV{PINHOME};
$basedir = "$pindir/cheetahtool-0.1";
$pinexe = "Bin/pin -t $basedir/cheetahtool";
$cheetahopts = " -Csa -M16777216 -i16384 -a4 -b21 -l6 -n3";
$logdir = "$pindir/logs";


@apps = qw(ls);                        # nicknames
%dirs = ('ls', "$basedir");            # exe dir for the app
%commandlines = ('ls', "/bin/ls");     # commandline for each app 


if(! -d $logdir){ 
    mkdir $logdir;
}

foreach $cache qw(dcache icache){
    foreach $app (@apps){
	print "$app:\n";
	
	print "cd $basedir/$dirs{$app}\n";
	chdir "$basedir/$dirs{$app}";
	
	print "$pindir/$pinexe $cheetahopts --$cache -- $commandlines{$app}\n\n";
	@output = `$pindir/$pinexe $cheetahopts --$cache -- $commandlines{$app}`;
	
	foreach $line (@output){
	    print $line;
	}
	
	`cp data.out $logdir/$app-$cache.out`;
	`tail -19 data.out > cache.out`;
	
	open (GP, "|gnuplot -persist -xrm \'gnuplot*line2Color:white\'") or die "no gnuplot";
	
#setup the plot
	print GP "set terminal postscript color; set output '$logdir/$app-$cache.ps'\n";
	
	
	print GP "set key title \'Associativity\'\n";
	print GP "set title \'$app $cache\'\n";
	print GP "set xlabel \'size (KB)\'\n";
	print GP "set ylabel \'miss rate\'\n";
	print GP "set logscale x 2\n";
	print GP "set xrange [4:32768]\n";
#set yrange [0:.01];
	print GP "plot \'cache.out\' using (\$1*64*1/1024):2 with linespoints title \'1\', ";
	print GP "    \'cache.out\' using  (\$1*64*2/1024):3 with linespoints title \'2\', ";
	print GP "    \'cache.out\' using  (\$1*64*4/1024):5 with linespoints title \'4\', ";
	print GP "    \'cache.out\' using  (\$1*64*8/1024):9 with linespoints title \'8\'\n";
	close GP;
    }
}
chdir "$pindir";
